Coverage for test_emr.py: 100%

# Coverage for test_emr.py : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | # -*- coding: utf-8 -*- import pytest from jungle import cli @pytest.mark.parametrize('emr_name', [ ('*'), ('cluster-*'), ('cluster-02'), ('dummy-cluster'), ]) def test_emr_ls(runner, emr, emr_name): """jungle rds ls test""" result = runner.invoke(cli.cli, ['emr', 'ls', emr_name]) assert result.exit_code == 0